/*
 * Programm: GetMousePos
 *
 * Dieses kleine Tool liefert die aktuelle Mausposition als String im Format <x>|<y> zurück.
 *
 * Code basiert auf http://rosettacode.org/wiki/Get_mouse_position.
 *
 * Author:  Thorsten Bruns  <thorsten.bruns@gmx.de>
 * Version: V0.2alpha
 *
 * History:
 * Version      Datum       Name         Beschreibung
 * """"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
 * V0.1         24.12.2013  Bruns        Erste lauffähige Version, entlassen in die Wildniss
 */

#include <stdio.h>
#include <X11/Xlib.h>
#include <stdlib.h>

int main() {
  Display       *d;
  Window        inwin;
  Window        inchildwin;
  int           rootx, rooty;
  int           childx, childy;
  Atom          atom_type_prop;
  int           actual_format;
  unsigned int  mask;
  unsigned long n_items, bytes_after_ret;
  Window        *props;

  /* Wir sprechen hiermit den Standardbildschirm an
   * wird in einer Mehrmonitorumgebung vermutlich nicht einwandfrei funktionieren 
   */
  d = XOpenDisplay(NULL);

  /* das aktive Fenster ermitteln (keine Fehlerbehandlung!)- der Client muss freedesktop-kompatibel sein */
  (void)XGetWindowProperty(d, DefaultRootWindow(d),
                           XInternAtom(d, "_NET_ACTIVE_WINDOW", True),
                           0, 1, False, AnyPropertyType,
                           &atom_type_prop, &actual_format,
                           &n_items, &bytes_after_ret, (unsigned char**)&props);

  /* jetzt die Position des Mauszeigers abfragen. Wir erhalten das sowohl rel. zum Fenster als auch absolut. */
  XQueryPointer(d, props[0], &inwin, &inchildwin,
                &rootx, &rooty, &childx, &childy, &mask);
  /* Jetzt noch die absoluten Koordinaten ausgeben und wir sind fertig */
  printf("%d|%d\n", rootx, rooty);
  
  /* Aufräumen */
  XFree(props);
  (void)XCloseDisplay(d);
  return 0;
}
